if [ -z "$TMUX" ]; then
    # If we're in SSH
    if [ -n "$SSH_CLIENT" ] || [ -n "$SSH_TTY" ]; then
        echo "Welcome via SSH..."
    # If we're in a TTY without X
    elif [ -z "$DISPLAY" ]; then
        # Optional X start code commented out
        # echo "Start X? ..."
        # startx
    # Regular terminal with no tmux
    else
        tmux_sessions=$(tmux ls 2>/dev/null)
        tmux_status=$?
        if [ $tmux_status -ne 0 ]; then
            echo "Press any key to cancel tmux autostart..."
            read -t 0.7 -n 1 -s -r
            if [ $? -ne 0 ]; then
                tmux new -s default
            fi
        else
            tmux attach -t default || tmux new -s default
        fi
    fi
fi

# tmux project launcher function
function tmuxLauncher {
    selected_dir=$(/bin/fd --base-directory ~/Dev --search-path . -t d -d 2 | fzf)
    if [[ -n "$selected_dir" ]]; then
        if git rev-parse --git-dir &>/dev/null; then
            tmux rename-window "$selected_dir"
            cd "$HOME/Dev/$selected_dir"
        else
            tmux new-window -n "$selected_dir" -c "$HOME/Dev/$selected_dir"
        fi
    fi
    zle reset-prompt
}

zle -N tmuxLauncher
bindkey "^t" tmuxLauncher
